<a id="packages.valory.skills.oracle_abci.behaviours"></a>

# packages.valory.skills.oracle`_`abci.behaviours

This module contains the behaviours for the 'abci' skill.

<a id="packages.valory.skills.oracle_abci.behaviours.OracleAbciAppConsensusBehaviour"></a>

## OracleAbciAppConsensusBehaviour Objects

```python
class OracleAbciAppConsensusBehaviour(AbstractRoundBehaviour)
```

This behaviour manages the consensus stages for the price estimation.

